@@ -16,12 +16,6 @@ register_worker({ phase => 'check' }, sub {
   return Status->error("macsuck skipped: $device not yet discovered")
     unless $device->in_storage;
 
-  return Status->info("macsuck skipped: $device is pseudo-device")
-    if $device->is_pseudo;
-
-  return Status->info("macsuck skipped: $device has no layer 2 capability")
-    unless $device->has_layer(2);
-
   return Status->info("macsuck skipped: $device is not macsuckable")
     unless is_macsuckable_now($device);
 
